==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/islamic-civil.js <==
define({ root:

//begin v1.x content
{
	"field-quarter-short-relative+0": "this quarter",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"field-quarter-short-relative+1": "next quarter",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "Year",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "HH:mm",
	"field-minute": "Minute",
	"field-month-narrow-relative+-1": "last month",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"field-thu-short-relative+0": "this Thursday",
	"field-day-short-relative+-1": "yesterday",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "next Thursday",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-year-narrow": "Year",
	"field-year-narrow-relative+0": "this year",
	"field-tue-relative+0": "this Tuesday",
	"field-year-narrow-relative+1": "next year",
	"field-tue-relative+1": "next Tuesday",
	"field-second-short": "Second",
	"dayPeriods-format-narrow-am": "AM",
	"dateFormatItem-MMMd": "MMM d",
	"dayPeriods-format-abbr-am": "AM",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Sunday",
	"timeFormat-medium": "HH:mm:ss",
	"field-mon-short-relative+0": "this Monday",
	"field-sun-narrow-relative+1": "next Sunday",
	"field-mon-short-relative+1": "next Monday",
	"field-second-relative+0": "now",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"AH"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"field-month-short": "Month",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-day": "Day",
	"field-year-relative+-1": "last year",
	"dayPeriods-format-wide-am": "AM",
	"field-sat-short-relative+-1": "last Saturday",
	"field-hour-relative+0": "this hour",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "last Saturday",
	"field-second": "Second",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "G y MMMM d",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"field-hour-short-relative+0": "this hour",
	"field-quarter": "Quarter",
	"field-week-short": "Week",
	"field-day-narrow-relative+0": "today",
	"field-day-narrow-relative+1": "tomorrow",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"field-month-short-relative+-1": "last month",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "G y MMM",
	"field-month": "Month",
	"field-day-narrow": "Day",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "Minute",
	"field-dayperiod": "Dayperiod",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormat-medium": "G y MMM d",
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"eraAbbr": [
		"AH"
	],
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-second-narrow": "Second",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-day-narrow-relative+-1": "yesterday",
	"field-year-short": "Year",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "last quarter",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "MM-dd",
	"field-minute-narrow-relative+0": "this minute",
	"field-hour": "Hour",
	"months-format-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dateFormat-full": "G y MMMM d, EEEE",
	"field-month-relative+-1": "last month",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "Quarter",
	"field-sat-narrow-relative+0": "this Saturday",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-fri-relative+1": "next Friday",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"field-sun-short-relative+0": "this Sunday",
	"field-sun-short-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last quarter",
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-Ehm": "E h:mm a",
	"months-format-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"timeFormat-long": "HH:mm:ss z",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormat-short": "GGGGG y-MM-dd",
	"field-thu-short-relative+-1": "last Thursday",
	"field-year-narrow-relative+-1": "last year",
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"field-mon-narrow-relative+-1": "last Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-thu-narrow-relative+-1": "last Thursday",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"dateFormatItem-H": "HH",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dateFormatItem-yyyy": "G y",
	"field-wed-short-relative+0": "this Wednesday",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"field-wed-short-relative+1": "next Wednesday",
	"field-sun-relative+-1": "last Sunday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-second-narrow-relative+0": "now",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "Day of the Week",
	"field-day-short-relative+0": "today",
	"field-day-short-relative+1": "tomorrow",
	"field-sat-relative+0": "this Saturday",
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "next Saturday",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"months-standAlone-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-MEd": "MM-dd, E",
	"dateFormatItem-y": "G y",
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-mon-short-relative+-1": "last Monday",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-thu-relative+-1": "last Thursday",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "Week",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-Ed": "d, E",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-quarter-narrow-relative+-1": "last quarter",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-year-short-relative+1": "next year",
	"field-fri-short-relative+0": "this Friday",
	"field-fri-short-relative+1": "next Friday",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-week-short-relative+-1": "last week",
	"field-hour-narrow-relative+0": "this hour",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-hour-short": "Hour",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-month-narrow": "Month",
	"field-hour-narrow": "Hour",
	"field-fri-narrow-relative+-1": "last Friday",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"eraNarrow": [
		"AH"
	],
	"field-tue-short-relative+-1": "last Tuesday",
	"field-minute-narrow": "Minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"dateFormatItem-EHm": "E HH:mm",
	"field-year-short-relative+-1": "last year",
	"field-zone": "Zone",
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-quarter-narrow": "Quarter",
	"field-sun-short-relative+-1": "last Sunday",
	"field-day-relative+-1": "yesterday",
	"dayPeriods-standAlone-abbr-am": "AM",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-Gy": "G y",
	"field-week-narrow": "Week",
	"field-era": "Era",
	"field-day-short": "Day",
	"field-fri-narrow-relative+0": "this Friday",
	"field-fri-narrow-relative+1": "next Friday",
	"dayPeriods-standAlone-wide-am": "AM"
}
//end v1.x content
});

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/islamic-civil.js <==
define({ root:

//begin v1.x content
{
	"field-quarter-short-relative+0": "this quarter",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"field-quarter-short-relative+1": "next quarter",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "Year",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "HH:mm",
	"field-minute": "Minute",
	"field-month-narrow-relative+-1": "last month",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"field-thu-short-relative+0": "this Thursday",
	"field-day-short-relative+-1": "yesterday",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "next Thursday",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-narrow": "Year",
	"field-era-short": "Era",
	"field-year-narrow-relative+0": "this year",
	"field-tue-relative+0": "this Tuesday",
	"field-year-narrow-relative+1": "next year",
	"field-tue-relative+1": "next Tuesday",
	"field-weekdayOfMonth": "Weekday Of Month",
	"field-second-short": "Second",
	"dayPeriods-format-narrow-am": "AM",
	"dateFormatItem-MMMd": "MMM d",
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-format-abbr-am": "AM",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Sunday",
	"timeFormat-medium": "HH:mm:ss",
	"field-mon-short-relative+0": "this Monday",
	"field-sun-narrow-relative+1": "next Sunday",
	"field-mon-short-relative+1": "next Monday",
	"field-second-relative+0": "now",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"AH"
	],
	"field-weekOfMonth": "Week Of Month",
	"dayPeriods-standAlone-abbr-pm": "PM",
	"field-month-short": "Month",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-day": "Day",
	"field-dayOfYear-short": "Day Of Year",
	"field-year-relative+-1": "last year",
	"dayPeriods-format-wide-am": "AM",
	"field-sat-short-relative+-1": "last Saturday",
	"field-hour-relative+0": "this hour",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "last Saturday",
	"field-second": "Second",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "G y MMMM d",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"field-hour-short-relative+0": "this hour",
	"field-quarter": "Quarter",
	"field-week-short": "Week",
	"field-day-narrow-relative+0": "today",
	"field-day-narrow-relative+1": "tomorrow",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"field-month-short-relative+-1": "last month",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "G y MMM",
	"field-month": "Month",
	"field-day-narrow": "Day",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "Minute",
	"field-dayperiod": "Dayperiod",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormat-medium": "G y MMM d",
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"eraAbbr": [
		"AH"
	],
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-second-narrow": "Second",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-day-narrow-relative+-1": "yesterday",
	"field-year-short": "Year",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "last quarter",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-dayperiod-narrow": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-dayOfYear": "Day Of Year",
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "MM-dd",
	"field-minute-narrow-relative+0": "this minute",
	"field-hour": "Hour",
	"months-format-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dateFormat-full": "G y MMMM d, EEEE",
	"field-month-relative+-1": "last month",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "Quarter",
	"field-sat-narrow-relative+0": "this Saturday",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-fri-relative+1": "next Friday",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"field-sun-short-relative+0": "this Sunday",
	"field-sun-short-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last quarter",
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-Ehm": "E h:mm a",
	"months-format-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"timeFormat-long": "HH:mm:ss z",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormat-short": "GGGGG y-MM-dd",
	"dateFormatItem-Bh": "h B",
	"field-thu-short-relative+-1": "last Thursday",
	"field-year-narrow-relative+-1": "last year",
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"field-mon-narrow-relative+-1": "last Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-thu-narrow-relative+-1": "last Thursday",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "Week Of Month",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dateFormatItem-yyyy": "G y",
	"field-wed-short-relative+0": "this Wednesday",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"field-wed-short-relative+1": "next Wednesday",
	"field-sun-relative+-1": "last Sunday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "now",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "Day of the Week",
	"field-day-short-relative+0": "today",
	"field-day-short-relative+1": "tomorrow",
	"field-sat-relative+0": "this Saturday",
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "next Saturday",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"months-standAlone-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-dayOfYear-narrow": "Day Of Year",
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-zone-narrow": "Zone",
	"dateFormatItem-y": "G y",
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-mon-short-relative+-1": "last Monday",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-thu-relative+-1": "last Thursday",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "Week",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-Ed": "d, E",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-quarter-narrow-relative+-1": "last quarter",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-dayperiod-short": "Dayperiod",
	"field-year-short-relative+1": "next year",
	"field-fri-short-relative+0": "this Friday",
	"field-fri-short-relative+1": "next Friday",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-week-short-relative+-1": "last week",
	"field-hour-narrow-relative+0": "this hour",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-zone-short": "Zone",
	"field-hour-short": "Hour",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-month-narrow": "Month",
	"field-hour-narrow": "Hour",
	"field-fri-narrow-relative+-1": "last Friday",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-era-narrow": "Era",
	"field-fri-relative+-1": "last Friday",
	"eraNarrow": [
		"AH"
	],
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-minute-narrow": "Minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"dateFormatItem-EHm": "E HH:mm",
	"field-year-short-relative+-1": "last year",
	"field-zone": "Zone",
	"dateFormatItem-MMMEd": "MMM d, E",
	"field-weekOfMonth-narrow": "Week Of Month",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "Day of the Week",
	"field-quarter-narrow": "Quarter",
	"field-sun-short-relative+-1": "last Sunday",
	"field-day-relative+-1": "yesterday",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-weekday-short": "Day of the Week",
	"dateFormatItem-Bhm": "h:mm B",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-Gy": "G y",
	"field-week-narrow": "Week",
	"field-era": "Era",
	"field-day-short": "Day",
	"field-fri-narrow-relative+0": "this Friday",
	"field-fri-narrow-relative+1": "next Friday",
	"dayPeriods-standAlone-wide-am": "AM"
}
//end v1.x content
});
